[openssh-commits] [openssh] 01/01: upstream: test the correct configuration option name

git+noreply at mindrot.org git+noreply at mindrot.org
Fri Jun 8 00:31:50 AEST 2018


This is an automated email from the git hooks/post-receive script.

djm pushed a commit to branch master
in repository openssh.

commit 57379dbd013ad32ee3f9989bf5f5741065428360
Author: djm at openbsd.org <djm at openbsd.org>
Date:   Thu Jun 7 14:29:43 2018 +0000

    upstream: test the correct configuration option name
    
    OpenBSD-Regress-ID: 492279ea9f65657f97a970e0e7c7fd0b339fee23
---
 regress/forward-control.sh | 18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

diff --git a/regress/forward-control.sh b/regress/forward-control.sh
index c22ca223..3b1f69a7 100644
--- a/regress/forward-control.sh
+++ b/regress/forward-control.sh
@@ -1,4 +1,4 @@
-#	$OpenBSD: forward-control.sh,v 1.6 2018/06/06 18:25:33 djm Exp $
+#	$OpenBSD: forward-control.sh,v 1.7 2018/06/07 14:29:43 djm Exp $
 #	Placed in the Public Domain.
 
 tid="sshd control of local and remote forwarding"
@@ -210,20 +210,20 @@ rperm_tests() {
 	cp ${OBJ}/authorized_keys_${USER}.bak  ${OBJ}/authorized_keys_${USER}
 	_prefix="AllowTcpForwarding=$_tcpfwd"
 
 	# PermitRemoteOpen via sshd_config that doesn't match
 	( cat ${OBJ}/sshd_proxy.bak ;
 	  echo "AllowTcpForwarding $_tcpfwd" ;
-	  echo "PermitRemoteOpen $_badfwd1 $_badfwd2" ) \
+	  echo "PermitListen $_badfwd1 $_badfwd2" ) \
 	    > ${OBJ}/sshd_proxy
-	check_lfwd $_nopermit_lfwd "$_prefix, !PermitRemoteOpen"
-	check_rfwd $_nopermit_rfwd "$_prefix, !PermitRemoteOpen"
-	# PermitRemoteOpen via sshd_config that does match
+	check_lfwd $_nopermit_lfwd "$_prefix, !PermitListen"
+	check_rfwd $_nopermit_rfwd "$_prefix, !PermitListen"
+	# PermitListen via sshd_config that does match
 	( cat ${OBJ}/sshd_proxy.bak ;
 	  echo "AllowTcpForwarding $_tcpfwd" ;
-	  echo "PermitRemoteOpen $_badfwd1 $_goodfwd $_badfwd2" ) \
+	  echo "PermitListen $_badfwd1 $_goodfwd $_badfwd2" ) \
 	    > ${OBJ}/sshd_proxy
-	check_lfwd $_plain_lfwd "$_prefix, PermitRemoteOpen"
-	check_rfwd $_plain_rfwd "$_prefix, PermitRemoteOpen"
+	check_lfwd $_plain_lfwd "$_prefix, PermitListen"
+	check_rfwd $_plain_rfwd "$_prefix, PermitListen"
 }
 
 #   permit-remote-open      none          mismatch         match
@@ -210,20 +210,20 @@ rperm_tests() {
 	_prefix="AllowTcpForwarding=$_tcpfwd"
 
-	# PermitRemoteOpen via sshd_config that doesn't match
+	# PermitListen via sshd_config that doesn't match
 	( cat ${OBJ}/sshd_proxy.bak ;
 	  echo "AllowTcpForwarding $_tcpfwd" ;

-- 
To stop receiving notification emails like this one, please contact
djm at mindrot.org.


More information about the openssh-commits mailing list